diff --git a/src/net/java/sip/communicator/service/protocol/ChatRoom.java b/src/net/java/sip/communicator/service/protocol/ChatRoom.java
index d8bf5f858..55566f296 100644
--- a/src/net/java/sip/communicator/service/protocol/ChatRoom.java
+++ b/src/net/java/sip/communicator/service/protocol/ChatRoom.java
@@ -147,7 +147,7 @@ public void setSubject(final String subject)
* @return the nickname currently being used by the local user in the
* context of the local chat room.
*/
- public String getNickname();
+ public String getUserNickname();
/**
* Changes the the local user's nickname in the context of this chatroom.
@@ -187,7 +187,7 @@ public void removeLocalUserStatusListener(
* @param listener a participant status listener.
*/
public void addParticipantStatusListener(
- ChatRoomParticipantStatusListener listener);
+ ChatRoomMemberListener listener);
/**
* Removes a listener that was being notified of changes in the status of
@@ -197,7 +197,7 @@ public void addParticipantStatusListener(
* @param listener a participant status listener.
*/
public void removeParticipantStatusListener(
- ChatRoomParticipantStatusListener listener);
+ ChatRoomMemberListener listener);
/**
* Invites another user to this room.
@@ -214,11 +214,11 @@ public void removeParticipantStatusListener(
public void invite(String userAddress, String reason);
/**
- * Returns a List of Contacts corresponding to all
+ * Returns a List of ChatRoomMembers corresponding to all
* members currently participating in this room.
*
* @return a List of Contact corresponding to all room
* members.
* @throws OperationFailedException if we fail retrieving the list of room
* participants.
*/
@@ -271,11 +271,20 @@ public Message createMessage(byte[] content, String contentType,
* Sends the message to the destination indicated by the
* to contact.
* @param message the Message to send.
- * @throws java.lang.IllegalStateException if the underlying stack is
- * not registered or initialized or if the chat room is not joined.
+ * @throws OperationFailedException if sending the message fails for some
+ * reason.
*/
public void sendMessage(Message message)
- throws IllegalStateException;
+ throws OperationFailedException;
+
+
+ /**
+ * Returns a reference to the provider that created this room.
+ *
+ * @return a reference to the ProtocolProviderService instance
+ * that created this room.
+ */
+ public ProtocolProviderService getParentProvider();
//include - roominfo
/** @todo include room info */
@@ -214,11 +214,11 @@ public void removeParticipantStatusListener(
* members currently participating in this room.
*
- * @return a List of Contact corresponding to all room
- * members.
+ * @return a List of ChatRoomMember instances
+ * corresponding to all room members.
* @throws OperationFailedException if we fail retrieving the list of room
* participants.